@@ -1,5 +1,4 @@
 # -*- encoding: binary -*-
-#
 # :enddoc:
 
 # this is used to augment Kgio::Socket and Kgio::Pipe-enhanced classes
@@ -8,10 +7,15 @@
 module Rainbows::Fiber::IO::Methods
   RD = Rainbows::Fiber::RD
   WR = Rainbows::Fiber::WR
+  ZZ = Rainbows::Fiber::ZZ
   attr_accessor :f
 
+  def read_expire
+    ZZ[Fiber.current] = super
+  end
+
   # for wrapping output response bodies
-  def each(&block)
+  def each
     if buf = kgio_read(16384)
       yield buf
       yield buf while kgio_read(16384, buf)
@@ -30,6 +34,7 @@ module Rainbows::Fiber::IO::Methods
     @f = Fiber.current
     RD[fd] = self
     Fiber.yield
+    ZZ.delete @f
     RD[fd] = nil
   end
 
